import pytest

from src.api.db import Base, SessionLocal, engine
from src.api.models.flight import Flight

session = SessionLocal()
base = Base


@pytest.fixture(scope="module")
def test_database():
    base.metadata.drop_all(bind=engine)
    base.metadata.create_all(bind=engine)
    yield session
    session.close()
    base.metadata.drop_all(bind=engine)


@pytest.fixture(scope="module")
def create_flight():
    def create_flight(flight: Flight):
        db_flight = Flight(
            flight_code=flight.flight_code,
            status=flight.status,
            origin=flight.origin,
            destination=flight.destination,
            departure_time=flight.departure_time,
            arrival_time=flight.arrival_time,
            gate=flight.gate,
        )
        session.add(db_flight)
        session.commit()
        session.refresh(db_flight)
        return db_flight

    return create_flight


@pytest.fixture(scope="module")
def get_flight():
    def get_flight(flight_id: int):
        return session.query(Flight).filter(Flight.id == flight_id).first()

    return get_flight
